@@ -14,7 +14,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.22.2"
+version = "1.23.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -68,7 +68,7 @@ defaults = {
     "ccache_size": "5G",
     "is_default_channel": True,
     "cipher": "aes-xts-plain64",
-    "config": os.path.expanduser("~") + "/.config/pmbootstrap.cfg",
+    "config": (os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser("~/.config")) + "/pmbootstrap.cfg",
     "device": "qemu-amd64",
     "extra_packages": "none",
     "fork_alpine": False,
@@ -83,7 +83,7 @@ defaults = {
     "keymap": "",
     "log": "$WORK/log.txt",
     "mirror_alpine": "http://dl-2.alpinelinux.org/alpine/",
-    "mirrors_postmarketos": ["http://postmarketos1.brixit.nl/postmarketos/"],
+    "mirrors_postmarketos": ["http://mirror.postmarketos.org/postmarketos/"],
     "nonfree_firmware": True,
     "nonfree_userland": False,
     "port_distccd": "33632",
@@ -342,6 +342,7 @@ deviceinfo_attributes = [
     "kernel_cmdline",
     "generate_bootimg",
     "bootimg_qcdt",
+    "bootimg_mtk_mkimage",
     "bootimg_dtb_second",
     "flash_offset_base",
     "flash_offset_kernel",
@@ -552,6 +553,12 @@ aportgen = {
     }
 }
 
+# Use a deterministic mirror URL instead of CDN for aportgen. Otherwise we may
+# generate a pmaport that wraps an apk from Alpine (e.g. musl-armv7) locally
+# with one up-to-date mirror given by the CDN. But then the build will fail if
+# CDN picks an outdated mirror for CI or BPO.
+aportgen_mirror_alpine = "http://dl-2.alpinelinux.org/alpine/"
+
 #
 # NEWAPKBUILD
 # Options passed through to the "newapkbuild" command from Alpine Linux. They
