@@ -294,9 +294,21 @@ def setup_keymap(args):
                         output="interactive")
 
         # Check xorg config
-        config = pmb.chroot.root(args, ["grep", "-rl", "XkbLayout", "/etc/X11/xorg.conf.d/"],
-                                 suffix, check=False, output_return=True)
+        config = None
+        if os.path.exists(f"{args.work}/chroot_{suffix}/etc/X11/xorg.conf.d"):
+            config = pmb.chroot.root(args, ["grep", "-rl", "XkbLayout",
+                                            "/etc/X11/xorg.conf.d/"],
+                                     suffix, check=False, output_return=True)
         if config:
+            # Nokia n900 (RX-51) randomly merges some keymaps so we
+            # have to specify a composite keymap for a few countries. See:
+            # https://gitlab.freedesktop.org/xkeyboard-config/xkeyboard-config/-/blob/master/symbols/nokia_vndr/rx-51
+            if variant == "rx51_fi" or variant == "rx51_se":
+                layout = "fise"
+            if variant == "rx51_da" or variant == "rx51_no":
+                layout = "dano"
+            if variant == "rx51_pt" or variant == "rx51_es":
+                layout = "ptes"
             # Multiple files can contain the keyboard layout, take last
             config = config.splitlines()[-1]
             old_text = "Option *\\\"XkbLayout\\\" *\\\".*\\\""
@@ -402,7 +414,8 @@ def embed_firmware(args):
                                "bs=" + str(step), "seek=" + str(offset)])
 
 
-def sanity_check_sdcard(device):
+def sanity_check_sdcard(args):
+    device = args.sdcard
     device_name = os.path.basename(device)
     if not os.path.exists(device):
         raise RuntimeError("{} doesn't exist, is the sdcard plugged?".format(device))
@@ -413,6 +426,30 @@ def sanity_check_sdcard(device):
             raise RuntimeError("{} is read-only, is the sdcard locked?".format(device))
 
 
+def sanity_check_sdcard_size(args):
+    device = args.sdcard
+    devpath = os.path.realpath(device)
+    sysfs = '/sys/class/block/{}/size'.format(devpath.replace('/dev/', ''))
+    if not os.path.isfile(sysfs):
+        # This is a best-effort sanity check, continue if it's not checkable
+        return
+
+    with open(sysfs) as handle:
+        raw = handle.read()
+
+    # Size is in 512-byte blocks
+    size = int(raw.strip())
+    human = "{:.2f} GiB".format(size / 2 / 1024 / 1024)
+
+    # Warn if the size is larger than 100GiB
+    if size > (100 * 2 * 1024 * 1024):
+        if not pmb.helpers.cli.confirm(args, f"WARNING: The target disk ({devpath}) is"
+                                             " larger than a usual SD card (>100GiB)."
+                                             " Are you sure you want to overwrite"
+                                             f" this {human} disk?", no_assumptions=True):
+            raise RuntimeError("Aborted.")
+
+
 def sanity_check_ondev_version(args):
     arch = args.deviceinfo["arch"]
     package = pmb.helpers.package.get(args, "postmarketos-ondev", arch)
@@ -609,7 +646,8 @@ def install_on_device_installer(args, step, steps):
 def install(args):
     # Sanity checks
     if not args.android_recovery_zip and args.sdcard:
-        sanity_check_sdcard(args.sdcard)
+        sanity_check_sdcard(args)
+        sanity_check_sdcard_size(args)
     if args.on_device_installer:
         sanity_check_ondev_version(args)
 
